import { NextRequest, NextResponse } from "next/server";
import { searchDocs } from "@/app/common/documentation";

export async function GET(request: NextRequest) {
  // The query to search for
  const query: string | null = request.nextUrl.searchParams.get("query");

  // No query provided
  if (!query) {
    return new NextResponse(JSON.stringify({ error: "No query provided" }), { status: 400 });
  }

  // Don't allow queries less than 3 characters
  if (query.length < 3) {
    return new NextResponse(JSON.stringify({ error: "Query must be at least 3 characters" }), { status: 400 });
  }

  // Return the search results
  return new NextResponse(JSON.stringify(searchDocs(query)));
}
